/*-------------------------------------------------------------------------+
| Copyright 2023 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.variability.analysis;

import java.util.List;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.variability.model.features.configuration.VariantConfiguration;

/**
 * Class representing one error identified by a product line analysis run.
 * 
 * @author bayha
 */
public class ProductLineConstraintViolation {

	/** The model elements which cause a constraint violation. */
	protected List<EObject> violatingElements;

	/** The violated constraint. */
	protected IProductLineConstraint constraint;

	/** The configuration which will reuslt in a model variant which violates the constraint. */
	private VariantConfiguration violatingConfiguration;

	/** Constructor. */
	public ProductLineConstraintViolation(IProductLineConstraint constraint,
			List<EObject> violatingElements, VariantConfiguration violatingConfiguration) {
		this.constraint = constraint;
		this.violatingElements = violatingElements;
		this.violatingConfiguration = violatingConfiguration;
	}

	/** Returns the elements which causes the violation. */
	public List<EObject> getViolatingElements() {
		return violatingElements;
	}

	/** Returns the error message. */
	public String getErrorMessage() {
		return constraint.createErrorMessage(violatingElements, violatingConfiguration);
	}

	/** Returns the constraint that has been violated. */
	public IProductLineConstraint getConstraint() {
		return constraint;
	}

	/** Returns the configuration which will violate the constraint. */
	public VariantConfiguration getViolatingConfiguration() {
		return violatingConfiguration;
	}
}
